@@ -16,8 +16,7 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -1233,6 +1232,29 @@ get_home_relative_file (const char *partial_uri)
 }
 
 
+GFile *
+get_user_config_subdirectory (const char *child_name,
+			      gboolean    create_child)
+{
+	char   *full_path;
+	GFile  *file;
+	GError *error = NULL;
+
+	full_path = g_strconcat (g_get_user_config_dir (), "/", child_name, NULL);
+	file = g_file_new_for_path (full_path);
+	g_free (full_path);
+
+	if  (create_child && ! make_directory_tree (file, 0700, &error)) {
+		g_warning ("%s", error->message);
+		g_error_free (error);
+		g_object_unref (file);
+		file = NULL;
+	}
+
+	return file;
+}
+
+
 const char *
 remove_host_from_uri (const char *uri)
 {
